/*
    psftools: Manipulate console fonts in the .PSF format
    Copyright (C) 2002  John Elliott

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "psfio.h"

/* Force a PSF file to be v1 or v2 */
psf_errno_t psf_force_v1(PSF_FILE *f)
{
	psf_byte *ndata;
	int nc, maxc, maxc2, y, wb;

	if (f->psf_magic == PSF1_MAGIC) return PSF_E_OK;
	if (!f->psf_data || !f->psf_height) return PSF_E_EMPTY;

	maxc = 256;
	if (f->psf_length > 256) maxc = 512;

	maxc2 = maxc;
	if (maxc2 < f->psf_length) maxc2 = f->psf_length;

	ndata = malloc(maxc * f->psf_height);
	memset(ndata, 0, maxc * f->psf_height);

	if (!ndata) return PSF_E_NOMEM;
	wb = (f->psf_width + 7) / 8;
	for (nc = 0; nc < maxc2; nc++)
	{
		for (y = 0; y < f->psf_height; y++)
		{
			ndata[f->psf_height * nc + y] =
				f->psf_data[f->psf_charlen * nc + y * wb]; 
		}
	}
	free(f->psf_data);
	f->psf_data = ndata;
	f->psf_magic = PSF1_MAGIC;
	f->psf_version = 0;
	f->psf_hdrlen = 4;
	f->psf_length = maxc;
	f->psf_charlen = f->psf_height;
	f->psf_width = 8;
	return PSF_E_OK;
}



psf_errno_t psf_force_v2(PSF_FILE *f)
{
	f->psf_magic = PSF_MAGIC;
	f->psf_version = 0;
	f->psf_hdrlen = 32;
	return PSF_E_OK;
}

