
#include "cnvshell.h"
#include "psflib.h"
#include <limits.h>

#ifndef PATH_MAX
# ifdef CPM
#  define PATH_MAX 20
# else
#  define PATH_MAX 256
# endif
#endif

PSF_FILE oldpsf, newpsf;
static int translation[512];
static char linebuf[20];
static char trfile[PATH_MAX];

int load_transfile(char *transfile)
{
	int from, to;
	FILE *fp;

	if (!strcmp(transfile, "-")) fp = stdin;
	else fp = fopen(transfile, "r");

	if (!fp) 
	{
		perror(transfile);
		return -1;
	}

	do
	{
		fgets(linebuf, 20, fp);	
		if (feof(fp)) break;

		sscanf(linebuf, "%d,%d", &from, &to);

		if (from < 512 && from >= 0 && to < 512 && to >= 0)
		{
			translation[from] = to;
		}	
	} while (!feof(fp));

	if (!strcmp(transfile, "-")) fclose(fp);
	return 0;
}

/* ddash = 1 if option started with a double-dash; else 0 */
/* Return NULL if OK, else error string */
char *cnv_set_option(int ddash, char *variable, char *value)
{
	if (!stricmp(variable,"transfile"))
	{
		strncpy(trfile, value, PATH_MAX);
		trfile[PATH_MAX - 1] = 0;
		return NULL;
	}
	return "Invalid option name";	

}


/* Return help string */
extern char *cnv_help(void)
{
    static char buf[150];

    sprintf(buf, "Syntax: %s psf_file psf_file --transfile=filename\n", 
		cnv_progname);
    return buf;

}
/* Program name */
char *cnv_progname = "PSFREMAP";



char *cnv_execute(FILE *infile, FILE *outfile)
{
	int r;
	psf_dword maxc, nchar;
	for (nchar = 0; nchar < 512; nchar++) translation[nchar] = nchar;

	if (trfile[0])
	{
		if (load_transfile(trfile)) 
			return "Could not load translation table file.";
	}
	psf_file_new(&oldpsf);
	psf_file_new(&newpsf);
	r = psf_file_read(&oldpsf, infile);

        if (r != PSF_E_OK) return psf_error_string(r);
	r = psf_file_create(&newpsf, oldpsf.psf_width,
				oldpsf.psf_height, oldpsf.psf_length,
				oldpsf.psf_flags & 1);
	if (r != PSF_E_OK)
	{
		psf_file_delete(&oldpsf);
		return psf_error_string(r);
	}
	maxc = psf_count_chars(&oldpsf);
	for (nchar = 0; nchar < maxc; nchar++)
	{
		psf_byte *f, *t;
		int newc = translation[nchar]; 
		if (newc >= maxc) newc = nchar;
	
		f = oldpsf.psf_data + oldpsf.psf_charlen * nchar;
		t = newpsf.psf_data + newpsf.psf_charlen * newc;
		memcpy(t, f, oldpsf.psf_charlen);
	}
	if (psf_is_unicode(&oldpsf))
	{
		psf_unicode_dirent *ude;
		for (nchar = 0; nchar < maxc; nchar++)
		{
			ude = oldpsf.psf_dirents_used[nchar];
			while (ude) 
			{
				psf_unicode_add(&newpsf, nchar, ude->psfu_token);
				ude = ude->psfu_next;
			}
		}
	}
	r  = psf_file_write(&newpsf, outfile);
	psf_file_delete(&oldpsf);
	psf_file_delete(&newpsf);
	if (r != PSF_E_OK) return psf_error_string(r);
	return NULL;
}


